@@ -21,23 +21,22 @@
 
 #include <cmath>
 
-#include <QDebug>
-
 #include <KRandom>
 
 #include "board.h"
 #include "renderer.h"
+#include "debug.h"
 
 const int KBounceBall::BALL_ANIM_DELAY = 50;
 const qreal KBounceBall::BALL_RELATIVE_SIZE = 0.8;
 
 KBounceBall::KBounceBall( KBounceRenderer* renderer, KBounceBoard* board )
-: KGameRenderedItem(renderer,QLatin1String(""), board ), m_renderer( renderer ), m_board( board ),
+    : KGameRenderedItem(renderer,QLatin1String(""), board ), m_renderer( renderer ), m_board( board ),
     m_soundDelay( 0 ), m_size( QSize( 16, 16 ) ), m_framesNum( 0 ), m_xPos( 0 ), m_yPos( 0 ) 
 {
-	setSpriteKey(QStringLiteral("ball"));
-	resetPixmaps();
-	m_nextBoundingRect.setSize( QSizeF( BALL_RELATIVE_SIZE, BALL_RELATIVE_SIZE ) );
+    setSpriteKey(QStringLiteral("ball"));
+    resetPixmaps();
+    m_nextBoundingRect.setSize( QSizeF( BALL_RELATIVE_SIZE, BALL_RELATIVE_SIZE ) );
 }
 
 
@@ -47,72 +46,72 @@ KBounceBall::~KBounceBall()
 
 void KBounceBall::goForward()
 {
-   if ( m_reflectX )
-   {
-       m_velocity.x = -m_velocity.x;
-       m_reflectX = false;
-   }
-   
-   if ( m_reflectY )
-   {
-       qDebug() << "Reflecting ball Y";
-       m_velocity.y = -m_velocity.y;
-       m_reflectY = false;
-   }
+    if ( m_reflectX )
+    {
+        m_velocity.x = -m_velocity.x;
+        m_reflectX = false;
+    }
 
-   m_xPos += m_velocity.x;
-   m_yPos += m_velocity.y;
+    if ( m_reflectY )
+    {
+        qCDebug(KBOUNCE_LOG) << "Reflecting ball Y";
+        m_velocity.y = -m_velocity.y;
+        m_reflectY = false;
+    }
 
-   m_nextBoundingRect.moveTo( m_xPos + m_velocity.x, m_yPos + m_velocity.y );
+    m_xPos += m_velocity.x;
+    m_yPos += m_velocity.y;
+
+    m_nextBoundingRect.moveTo( m_xPos + m_velocity.x, m_yPos + m_velocity.y );
 }
 
 void KBounceBall::collide( const KBounceCollision& collision )
 {
     foreach ( const KBounceHit &hit, collision )
     {
-		if ( hit.type == TILE || hit.type == WALL )
-		{
-		    if ( hit.normal.x > 0 && m_velocity.x < 0 )
-			m_reflectX = true;
-		    if ( hit.normal.x < 0 && m_velocity.x > 0 )
-			m_reflectX = true;
-		    if ( hit.normal.y > 0 && m_velocity.y < 0 )
-			m_reflectY = true;
-		    if ( hit.normal.y < 0 && m_velocity.y > 0 )
-			m_reflectY = true;
-		}
+        if ( hit.type == TILE || hit.type == WALL )
+        {
+            if ( hit.normal.x > 0 && m_velocity.x < 0 )
+                m_reflectX = true;
+            if ( hit.normal.x < 0 && m_velocity.x > 0 )
+                m_reflectX = true;
+            if ( hit.normal.y > 0 && m_velocity.y < 0 )
+                m_reflectY = true;
+            if ( hit.normal.y < 0 && m_velocity.y > 0 )
+                m_reflectY = true;
+        }
     }
 }
 
 void KBounceBall::update()
 {
-	setFrame( frame()+1 );
-	setPos( m_board->mapPosition( QPointF( m_xPos, m_yPos ) ) );
+    setFrame( frame()+1 );
+    setPos( m_board->mapPosition( QPointF( m_xPos, m_yPos ) ) );
 }
 
 void KBounceBall::resize( const QSize& tileSize )
 {
-    qDebug() << "New size:" << tileSize;
+    qCDebug(KBOUNCE_LOG) << "New size:" << tileSize;
 
     m_size.setWidth( static_cast<int>( BALL_RELATIVE_SIZE * tileSize.width() ) );
     m_size.setHeight( static_cast<int> ( BALL_RELATIVE_SIZE * tileSize.height() ) );
-	setRenderSize(m_size);
+    setRenderSize(m_size);
     setPos( m_board->mapPosition( QPointF( m_xPos, m_yPos ) ) );
 }
 
 void KBounceBall::resetPixmaps()
 {
-	m_framesNum = frameCount();
-	setFrame( 1 );
+    m_framesNum = frameCount();
+    setFrame( 1 );
 }
 
 void KBounceBall::setRandomFrame()
 {
     int frame = 1;
     if ( m_framesNum > 1 )
-	{
-		frame = KRandom::random() % m_framesNum;
-	}
+    {
+        frame = KRandom::random() % m_framesNum;
+    }
     setFrame( frame );
 }
 
